==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/dataformat/CryptoDataFormatReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.dataformat;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.model.DataFormatDefinition;
import org.apache.camel.model.dataformat.CryptoDataFormat;

public class CryptoDataFormatReifier extends DataFormatReifier<CryptoDataFormat> {

    public CryptoDataFormatReifier(CamelContext camelContext, DataFormatDefinition definition) {
        super(camelContext, (CryptoDataFormat) definition);
    }

    @Override
    protected void prepareDataFormatConfig(Map<String, Object> properties) {
        properties.put("key", asRef(definition.getKeyRef()));
        properties.put("algorithmParameterSpec", asRef(definition.getAlgorithmParameterRef()));
        properties.put("initializationVector", asRef(definition.getInitVectorRef()));
        properties.put("shouldAppendHMAC", definition.getShouldAppendHMAC());
        properties.put("shouldInlineInitializationVector", definition.getInline());
        properties.put("algorithm", definition.getAlgorithm());
        properties.put("cryptoProvider", definition.getCryptoProvider());
        properties.put("macAlgorithm", definition.getMacAlgorithm());
        properties.put("bufferSize", definition.getBufferSize());
    }

}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/dataformat/CryptoDataFormatReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.dataformat;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.model.DataFormatDefinition;
import org.apache.camel.model.dataformat.CryptoDataFormat;

public class CryptoDataFormatReifier extends DataFormatReifier<CryptoDataFormat> {

    public CryptoDataFormatReifier(CamelContext camelContext, DataFormatDefinition definition) {
        super(camelContext, (CryptoDataFormat) definition);
    }

    @Override
    protected void prepareDataFormatConfig(Map<String, Object> properties) {
        properties.put("key", asRef(definition.getKey()));
        properties.put("algorithmParameterSpec", asRef(definition.getAlgorithmParameterSpec()));
        properties.put("initVector", asRef(definition.getInitVector()));
        properties.put("shouldAppendHMAC", definition.getShouldAppendHMAC());
        properties.put("inline", definition.getInline());
        properties.put("algorithm", definition.getAlgorithm());
        properties.put("cryptoProvider", definition.getCryptoProvider());
        properties.put("macAlgorithm", definition.getMacAlgorithm());
        properties.put("bufferSize", definition.getBufferSize());
    }

}
